@@ -35,7 +35,7 @@ EVAL_COMMAND_NAME = 'ep2_eval'
 KEY_UE_NO = 'ue'
 KEY_UE_TAG = 'tag'
 
-__version__ = '0.4.15'
+__version__ = '0.4.17'
 
 def relative_path(basedir, filename):
     """Creates a path relative to base"""
@@ -630,7 +630,7 @@ class Ep2:
 
 def verify_and_normalize_student_id(student_id) -> Result:
     import re
-    if re.match('\\d*', student_id) and len(student_id) <= 8:
+    if re.match('\\d*', student_id) and len(student_id) <= 8 and student_id != '':
         return Ok('0' * (8 - len(student_id)) + student_id)
     else:
         return Err('invalid student id: {}'.format(student_id))
