@@ -13,7 +13,7 @@ from ep2_core.common import *
 
 import csv
 
-KEY_UE_TA_POINTS = 'ta_points'
+KEY_UE_TA_POINTS = 'points'
 KEY_UE_ATTENDED = 'attended'
 KEY_UE_REMARKS = 'remarks'
 KEY_UE_FEEDBACK = 'feedback'
@@ -34,7 +34,7 @@ def pre_eval_csv_fieldnames(ep2: Ep2, ue: int) -> [str]:
 
 
 def pre_eval_csv_fieldnames_ta():
-    return [KEY_STUDENT_ID, KEY_UE_ATTENDED, KEY_UE_TA_POINTS, KEY_UE_REMARKS, KEY_UE_FEEDBACK]
+    return [KEY_UE_TA_POINTS, 'comment', 'team', 'member_1', 'member_2', 'member_3']
 
 
 @click.group()
@@ -490,7 +490,8 @@ def submit(ctx, group: str, ue: int):
 
     template = Template(file=ep2.template_path('pre_eval.tmpl'))
     template.tutor_gender = ep2.tutor_gender()
-    template.subtasks = ep2.get_exercise_subtasks(ue)
+    if curr_ue_type == ExerciseType.Normal:
+        template.subtasks = ep2.get_exercise_subtasks(ue)
 
     with open(exercise_csv_file, 'r', encoding='utf-8') as infile:
         reader = csv.DictReader(infile, fnames, KEY_INVALID, strict=True)
@@ -513,23 +514,24 @@ def submit(ctx, group: str, ue: int):
                     f_info.print_info()
                     exit(1)
 
-                if not check_row(row):
+                if curr_ue_type == ExerciseType.Normal and not check_row(row):
                     click.secho('Malformed file: %s. Missing column(s)!' % exercise_csv_file, fg='red')
                     f_info.print_info()
                     exit(1)
 
-                student_id = verify_and_normalize_student_id(row[KEY_STUDENT_ID])
-
-                if student_id.is_err():
-                    click.secho("[ERROR] unrecoverable error in student id normalization: {}".format(student_id.err()),
-                                fg='red', bold=True)
-                    return
-                else:
-                    student_id = student_id.ok()
-
-                stud_data = students[student_id]
-
                 if curr_ue_type == ExerciseType.Normal:
+                    student_id = verify_and_normalize_student_id(row[KEY_STUDENT_ID])
+
+                    if student_id.is_err():
+                        click.secho(
+                            "[ERROR] unrecoverable error in student id normalization: {}".format(student_id.err()),
+                            fg='red', bold=True)
+                        return
+                    else:
+                        student_id = student_id.ok()
+
+                    stud_data = students[student_id]
+
                     grading = row[KEY_UE_GRADING]   # for d in range(1, ep2.tests_for_exercise(ue) + 1)]
                     if any(grade == '_' for grade in grading):
                         click.secho('%s has not been graded yet. aborting!' % student_id, fg='red')
@@ -552,6 +554,23 @@ def submit(ctx, group: str, ue: int):
 
                     row[KEY_UE_GRADING] = template.grading
 
+                    template.ex_type = curr_ue_type.name
+                    template.student_feedback = row[KEY_UE_FEEDBACK]
+                    template.group = group.name
+                    template.student_gender = stud_data[KEY_STUDENT_GENDER]
+
+                    issue = template.__str__()
+                    click.echo(issue.replace('\n\n', '\n'))
+                    click.echo('Issue for %s - %s, %s\n' % (student_id, stud_data[KEY_STUDENT_NAME_LAST].upper(),
+                                                            stud_data[KEY_STUDENT_NAME_FIRST]))
+
+                    click.echo('\n' + ('=' * 30) + '\n')
+                    issues += [(student_id, issue)]
+
+                    row[KEY_UE_FEEDBACK] = escape_csv_string(row[KEY_UE_FEEDBACK])
+                    row[KEY_UE_REMARKS] = escape_csv_string(row[KEY_UE_REMARKS])
+                    row[KEY_STUDENT_ID] = student_id
+
                 elif curr_ue_type == ExerciseType.Team:
                     points = row[KEY_UE_TA_POINTS]
                     if points == '_':
@@ -562,22 +581,84 @@ def submit(ctx, group: str, ue: int):
 
                     template.points = points
                     template.grading = ''
-                template.ex_type = curr_ue_type.name
-                template.student_feedback = row[KEY_UE_FEEDBACK]
-                template.group = group.name
-                template.student_gender = stud_data[KEY_STUDENT_GENDER]
 
-                issue = template.__str__()
-                click.echo(issue.replace('\n\n', '\n'))
-                click.echo('Issue for %s - %s, %s\n' % (student_id, stud_data[KEY_STUDENT_NAME_LAST].upper(),
-                                                        stud_data[KEY_STUDENT_NAME_FIRST]))
+                    if row['member_1'] is not None and row['member_1'] != '':
+                        member_1 = verify_and_normalize_student_id(row['member_1'])
 
-                click.echo('\n' + ('=' * 30) + '\n')
-                issues += [(student_id, issue)]
+                        if member_1.is_err():
+                            click.secho(
+                                "[ERROR] unrecoverable error in student id normalization: {}".format(member_1.err()),
+                                fg='red', bold=True)
+                            return
+                        else:
+                            member_1 = member_1.ok()
 
-                row[KEY_UE_FEEDBACK] = escape_csv_string(row[KEY_UE_FEEDBACK])
-                row[KEY_UE_REMARKS] = escape_csv_string(row[KEY_UE_REMARKS])
-                row[KEY_STUDENT_ID] = student_id
+                        stud_data = students[member_1]
+
+                        template.ex_type = curr_ue_type.name
+                        template.student_feedback = row['comment']
+                        template.group = group.name
+                        template.student_gender = stud_data[KEY_STUDENT_GENDER]
+
+                        issue = template.__str__()
+                        click.echo(issue.replace('\n\n', '\n'))
+                        click.echo('Issue for %s - %s, %s\n' % (member_1, stud_data[KEY_STUDENT_NAME_LAST].upper(),
+                                                                stud_data[KEY_STUDENT_NAME_FIRST]))
+
+                        click.echo('\n' + ('=' * 30) + '\n')
+                        issues += [(member_1, issue)]
+
+                    if row['member_2'] is not None and row['member_2'] != '':
+                        member_2 = verify_and_normalize_student_id(row['member_2'])
+
+                        if member_2.is_err():
+                            click.secho(
+                                "[ERROR] unrecoverable error in student id normalization: {}".format(member_2.err()),
+                                fg='red', bold=True)
+                            return
+                        else:
+                            member_2 = member_2.ok()
+
+                        stud_data = students[member_2]
+
+                        template.ex_type = curr_ue_type.name
+                        template.student_feedback = row['comment']
+                        template.group = group.name
+                        template.student_gender = stud_data[KEY_STUDENT_GENDER]
+
+                        issue = template.__str__()
+                        click.echo(issue.replace('\n\n', '\n'))
+                        click.echo('Issue for %s - %s, %s\n' % (member_2, stud_data[KEY_STUDENT_NAME_LAST].upper(),
+                                                                stud_data[KEY_STUDENT_NAME_FIRST]))
+
+                        click.echo('\n' + ('=' * 30) + '\n')
+                        issues += [(member_2, issue)]
+
+                    if row['member_3'] is not None and row['member_3'] != '':
+                        member_3 = verify_and_normalize_student_id(row['member_3'])
+
+                        if member_3.is_err():
+                            click.secho(
+                                "[ERROR] unrecoverable error in student id normalization: {}".format(member_3.err()),
+                                fg='red', bold=True)
+                            return
+                        else:
+                            member_3 = member_3.ok()
+
+                        stud_data = students[member_3]
+
+                        template.ex_type = curr_ue_type.name
+                        template.student_feedback = row['comment']
+                        template.group = group.name
+                        template.student_gender = stud_data[KEY_STUDENT_GENDER]
+
+                        issue = template.__str__()
+                        click.echo(issue.replace('\n\n', '\n'))
+                        click.echo('Issue for %s - %s, %s\n' % (member_3, stud_data[KEY_STUDENT_NAME_LAST].upper(),
+                                                                stud_data[KEY_STUDENT_NAME_FIRST]))
+
+                        click.echo('\n' + ('=' * 30) + '\n')
+                        issues += [(member_3, issue)]
 
                 writer.writerow(row)
 
