@@ -30,6 +30,10 @@ def ex_test_csv_fieldnames():
             KEY_EX_TEST_FEEDBACK]
 
 
+def ex_test_ta_csv_fieldnames():
+    return [KEY_EX_TEST_POINTS, 'comment', KEY_EX_TEST_TEAM, 'member_1', 'member_2', 'member_3']
+
+
 class StudentIndex:
 
     def __init__(self, group: Ep2Group, ue: int, single: bool):
@@ -819,63 +823,166 @@ def submit(ctx, group, ue):
     with open(ex_test_csv_file, 'r') as infile:
         f_info.open_write(ex_test_csv_file_tmp, True)
         with open(ex_test_csv_file_tmp, 'w') as outfile:
-            reader = csv.DictReader(infile, ex_test_csv_fieldnames(), KEY_INVALID, strict=True)
+            if ue_type(ue) == ExerciseType.Normal:
+                reader = csv.DictReader(infile, ex_test_csv_fieldnames(), KEY_INVALID, strict=True)
 
-            headers = next(reader, None)
-            if not validate_headers(headers):
-                click.secho('Malformed file: %s. Invalid headers!' % ex_test_csv_file)
-                exit(1)
-
-            writer = csv.DictWriter(outfile, ex_test_csv_fieldnames(), lineterminator='\n')
-
-            writer.writeheader()
-
-            for row in reader:
-                if KEY_INVALID in row:
-                    click.secho('Malformed file: %s' % ex_test_csv_file)
-                    f_info.print_info()
+                headers = next(reader, None)
+                if not validate_headers(headers):
+                    click.secho('Malformed file: %s. Invalid headers!' % ex_test_csv_file)
                     exit(1)
 
-                if not check_row(row):
-                    click.secho('Malformed file: %s. Missing column(s)!' % ex_test_csv_file, fg='red')
-                    f_info.print_info()
+                writer = csv.DictWriter(outfile, ex_test_csv_fieldnames(), lineterminator='\n')
+
+                writer.writeheader()
+
+                for row in reader:
+                    if KEY_INVALID in row:
+                        click.secho('Malformed file: %s' % ex_test_csv_file)
+                        f_info.print_info()
+                        exit(1)
+
+                    if not check_row(row):
+                        click.secho('Malformed file: %s. Missing column(s)!' % ex_test_csv_file, fg='red')
+                        f_info.print_info()
+                        exit(1)
+
+                    student_id = verify_and_normalize_student_id(row[KEY_STUDENT_ID])
+
+                    if student_id.is_err():
+                        click.secho("[ERROR] unrecoverable error in student id normalization: {}".format(student_id.err()),
+                                    fg='red', bold=True)
+                        return
+                    else:
+                        student_id = student_id.ok()
+
+                    row[KEY_STUDENT_ID] = student_id
+
+                    if row[KEY_EX_TEST_POINTS] == '_':
+                        click.secho('%s has not been graded yet. aborting!' % student_id, fg='red')
+                        f_info.print_info()
+                        exit(1)
+
+                    row[KEY_EX_TEST_FEEDBACK] = escape_csv_string(row[KEY_EX_TEST_FEEDBACK])
+                    row[KEY_EX_TEST_REMARKS] = escape_csv_string(row[KEY_EX_TEST_REMARKS])
+
+                    details = student_details[student_id]
+
+                    template.points = row[KEY_EX_TEST_POINTS]
+                    template.student_feedback = row[KEY_EX_TEST_FEEDBACK]
+                    template.student_gender = details[KEY_STUDENT_GENDER]
+                    template.attended = True
+
+                    students.remove(student_id)
+
+                    issue = template.__str__()
+                    click.echo('Issue for student %s' % student_id, nl=True)
+                    click.echo(issue.replace('\n\n', '\n'), nl=True)
+                    click.echo(('=' * 30), nl=True)
+                    issues += [(student_id, issue)]
+
+                    writer.writerow(row)
+            else:
+                reader = csv.DictReader(infile, ex_test_ta_csv_fieldnames(), KEY_INVALID, strict=True)
+
+                headers = next(reader, None)
+                if not validate_headers(headers):
+                    click.secho('Malformed file: %s. Invalid headers!' % ex_test_csv_file)
                     exit(1)
 
-                student_id = verify_and_normalize_student_id(row[KEY_STUDENT_ID])
+                writer = csv.DictWriter(outfile, ex_test_ta_csv_fieldnames(), lineterminator='\n')
 
-                if student_id.is_err():
-                    click.secho("[ERROR] unrecoverable error in student id normalization: {}".format(student_id.err()),
-                                fg='red', bold=True)
-                    return
-                else:
-                    student_id = student_id.ok()
+                writer.writeheader()
 
-                row[KEY_STUDENT_ID] = student_id
+                for row in reader:
+                    if KEY_INVALID in row:
+                        click.secho('Malformed file: %s' % ex_test_csv_file)
+                        f_info.print_info()
+                        exit(1)
 
-                if row[KEY_EX_TEST_POINTS] == '_':
-                    click.secho('%s has not been graded yet. aborting!' % student_id, fg='red')
-                    f_info.print_info()
-                    exit(1)
+                    member1 = verify_and_normalize_student_id(row['member_1']) if row['member_1'] is not None else None
+                    member2 = verify_and_normalize_student_id(row['member_2']) if row['member_2'] is not None else None
+                    member3 = verify_and_normalize_student_id(row['member_3']) if row['member_3'] is not None else None
 
-                row[KEY_EX_TEST_FEEDBACK] = escape_csv_string(row[KEY_EX_TEST_FEEDBACK])
-                row[KEY_EX_TEST_REMARKS] = escape_csv_string(row[KEY_EX_TEST_REMARKS])
+                    if member1 is not None and member1.is_err():
+                        click.secho(
+                            "[ERROR] unrecoverable error in student id normalization: {}".format(member1.err()),
+                            fg='red', bold=True)
+                        return
+                    elif member1 is not None:
+                        member1 = member1.ok()
+                        row['member_1'] = member1
 
-                details = student_details[student_id]
+                    if member2 is not None and member2.is_err():
+                        click.secho(
+                            "[ERROR] unrecoverable error in student id normalization: {}".format(member2.err()),
+                            fg='red', bold=True)
+                        return
+                    elif member2 is not None:
+                        member2 = member2.ok()
+                        row['member_2'] = member2
 
-                template.points = row[KEY_EX_TEST_POINTS]
-                template.student_feedback = row[KEY_EX_TEST_FEEDBACK]
-                template.student_gender = details[KEY_STUDENT_GENDER]
-                template.attended = True
+                    if member3 is not None and member3.is_err():
+                        click.secho(
+                            "[ERROR] unrecoverable error in student id normalization: {}".format(member3.err()),
+                            fg='red', bold=True)
+                        return
+                    elif member3 is not None:
+                        member3 = member3.ok()
+                        row['member_3'] = member3
 
-                students.remove(student_id)
+                    if row[KEY_EX_TEST_POINTS] == '_' or row[KEY_EX_TEST_POINTS] == '':
+                        click.secho('%s has not been graded yet. aborting!' % row[KEY_EX_TEST_TEAM], fg='red')
+                        f_info.print_info()
+                        exit(1)
 
-                issue = template.__str__()
-                click.echo('Issue for student %s' % student_id, nl=True)
-                click.echo(issue.replace('\n\n', '\n'), nl=True)
-                click.echo(('=' * 30), nl=True)
-                issues += [(student_id, issue)]
+                    row['comment'] = escape_csv_string(row['comment'])
 
-                writer.writerow(row)
+                    if member1 is not None:
+                        details1 = student_details[member1]
+                        template.points = row[KEY_EX_TEST_POINTS]
+                        template.student_feedback = row['comment']
+                        template.student_gender = details1[KEY_STUDENT_GENDER]
+                        template.attended = True
+
+                        students.remove(member1)
+
+                        issue = template.__str__()
+                        click.echo('Issue for student %s' % member1, nl=True)
+                        click.echo(issue.replace('\n\n', '\n'), nl=True)
+                        click.echo(('=' * 30), nl=True)
+                        issues += [(member1, issue)]
+
+                    if member2 is not None:
+                        details2 = student_details[member2]
+                        template.points = row[KEY_EX_TEST_POINTS]
+                        template.student_feedback = row['comment']
+                        template.student_gender = details2[KEY_STUDENT_GENDER]
+                        template.attended = True
+
+                        students.remove(member2)
+
+                        issue = template.__str__()
+                        click.echo('Issue for student %s' % member2, nl=True)
+                        click.echo(issue.replace('\n\n', '\n'), nl=True)
+                        click.echo(('=' * 30), nl=True)
+                        issues += [(member2, issue)]
+
+                    if member3 is not None:
+                        details3 = student_details[member3]
+                        template.points = row[KEY_EX_TEST_POINTS]
+                        template.student_feedback = row['comment']
+                        template.student_gender = details3[KEY_STUDENT_GENDER]
+                        template.attended = True
+
+                        students.remove(member3)
+
+                        issue = template.__str__()
+                        click.echo('Issue for student %s' % member3, nl=True)
+                        click.echo(issue.replace('\n\n', '\n'), nl=True)
+                        click.echo(('=' * 30), nl=True)
+                        issues += [(member3, issue)]
+
+                    writer.writerow(row)
 
     for student in students:
         details = student_details[student]
